# Generated by Django 4.2.10 on 2024-02-16 16:48

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):
    dependencies = [
        ("minidebconf", "0008_alter_registration_shirt_size"),
    ]

    operations = [
        migrations.AlterField(
            model_name="registration",
            name="diet",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                to="minidebconf.diet",
                verbose_name="Diet",
            ),
        ),
        migrations.AlterField(
            model_name="registration",
            name="registration_type",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                to="minidebconf.registrationtype",
            ),
        ),
        migrations.AlterField(
            model_name="registration",
            name="shirt_size",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                to="minidebconf.shirtsize",
                verbose_name="Shirt size",
            ),
        ),
    ]
