# -*- coding: utf-8 -*-
# Generated by Django 1.11.18 on 2019-03-09 02:33
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('register', '0002_separate_childcare'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='accomm',
            name='special_needs',
        ),
    ]
