# Generated by Django 2.2.12 on 2020-05-30 18:35

import bursary.models
from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('bursary', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='bursaryreferee',
            name='referee',
            field=models.ForeignKey(limit_choices_to=bursary.models.check_bursaryreferee_permission, on_delete=django.db.models.deletion.PROTECT, to=settings.AUTH_USER_MODEL),
        ),
    ]
