# Generated by Django 4.2.8 on 2023-12-23 18:07

import django.core.validators
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("minidebconf", "0003_phone_registration_type"),
    ]

    operations = [
        migrations.AlterField(
            model_name="registration",
            name="phone_number",
            field=models.CharField(
                blank=True,
                max_length=24,
                null=True,
                validators=[
                    django.core.validators.RegexValidator(
                        inverse_match=True, regex="[^0-9() +-]"
                    )
                ],
            ),
        ),
    ]
