# -*- coding: utf-8 -*-
# Generated by Django 1.11.18 on 2019-02-04 19:33
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('register', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='CheckIn',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('t_shirt', models.BooleanField(default=False)),
                ('shoes', models.BooleanField(default=False)),
                ('swag', models.BooleanField(default=False)),
                ('nametag', models.BooleanField(default=False)),
                ('key_card', models.CharField(blank=True, max_length=5)),
                ('room_key', models.BooleanField(default=False)),
                ('checked_out', models.BooleanField(default=False)),
                ('returned_key', models.BooleanField(default=False)),
                ('returned_card', models.BooleanField(default=False)),
                ('notes', models.TextField(blank=True)),
                ('attendee', models.OneToOneField(on_delete=django.db.models.deletion.PROTECT, related_name='check_in', to='register.Attendee')),
            ],
        ),
    ]
