{% extends "register/form.html" %}
{% block extra_foot %}
  <script type="text/javascript">
    'use strict';
    $(function() {
      hookDependentVisibility($('#vaccinated'), $('#confirm_covid_tests'),
                              (function() {return !this.checked }));
    });
  </script>
{% endblock %}
